#include "stm8l.h"
#include "stm8l_gpio.h"
#include "stm8l_clk.h"
#include "stm8l_tim4.h"

#define PORT GPIOB
#define LED  GPIO_Pin_1
#define TIM4_PERIOD 124
#define TIM4_US_PERIOD 4

volatile uint16_t count;

INTERRUPT_HANDLER(IRQ_Handler_TIM4, 25)
{
	if (count)
		count--;

	TIM4_ClearITPendingBit(TIM4_IT_Update);
}

void delay_us(uint16_t us)
{
        TIM4_Cmd(DISABLE);       // stop


        TIM4_TimeBaseInit(TIM4_Prescaler_4, TIM4_US_PERIOD);
        TIM4_ClearFlag(TIM4_FLAG_Update);
        TIM4_ITConfig(TIM4_IT_Update, ENABLE);

        count = us>>1;

        TIM4_Cmd(ENABLE);       // let's go

        while(count);
}

void delay_ms(uint16_t ms)
{
        TIM4_Cmd(DISABLE);       // stop

        TIM4_TimeBaseInit(TIM4_Prescaler_128, TIM4_PERIOD);
        TIM4_ClearFlag(TIM4_FLAG_Update);
        TIM4_ITConfig(TIM4_IT_Update, ENABLE);

        count = ms;

        TIM4_Cmd(ENABLE);       // let's go

 	while(count);
}

void delay_us_check(uint16_t time)
{
    while (time)
    {
        delay_us(1000);
        time--;
    }
}

int main( void )
{
	// ---------   GPIO Config ---------------------------

	GPIO_DeInit(PORT);

	GPIO_Init(PORT, LED, GPIO_Mode_Out_PP_Low_Fast);

        // ---------- CLK Config -----------------------
        CLK_DeInit();
        CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);
	CLK_PeripheralClockConfig(CLK_Peripheral_TIM4, ENABLE);

	// ---------- TIM4 Init -----------------------------
	TIM4_DeInit();

	enableInterrupts();

	for(;;)
  	{
    		delay_ms(1000);
		GPIO_ResetBits(PORT, LED);
		delay_us_check(1000);
		GPIO_SetBits(PORT,LED);
  	}

}
