#include "stm8s.h"
#include "stm8s_gpio.h"
#include "stm8s_clk.h"
#include "stm8s_tim4.h"
#include "stm8s_uart1.h"
#include "stdio.h"

#define LED_PORT GPIOB
#define LED GPIO_PIN_5

#define TIM4_PERIOD       124

#define PUTCHAR_PROTOTYPE void putchar (char c)

ErrorStatus status = FALSE;
volatile uint16_t count;
uint16_t i;

INTERRUPT_HANDLER(IRQ_Handler_TIM4, 23)
{
	if (count)
		count--;

  	TIM4_ClearITPendingBit(TIM4_IT_UPDATE);
}

void delay_ms(uint16_t ms)
{
        TIM4_Cmd(DISABLE);       // stop
        TIM4_TimeBaseInit(TIM4_PRESCALER_128, TIM4_PERIOD);
        TIM4_ClearFlag(TIM4_FLAG_UPDATE);
        TIM4_ITConfig(TIM4_IT_UPDATE, ENABLE);

	count = ms;

        TIM4_Cmd(ENABLE);       // let's go

	while(count);
}


int main( void )
{

	// ----------- GPIO CONFIG -------------------
	GPIO_DeInit(LED_PORT);
	GPIO_Init(LED_PORT, LED, GPIO_MODE_OUT_PP_LOW_FAST);

	// ---------- CLK CONFIG -----------------------
	CLK_DeInit();

    	CLK_SYSCLKConfig(CLK_PRESCALER_CPUDIV1);
	CLK_SYSCLKConfig(CLK_PRESCALER_HSIDIV1); // set 16 MHz for CPU

	TIM4_DeInit();
	// uncomment if use HSE on Quartz
	//status = CLK_ClockSwitchConfig(CLK_SWITCHMODE_AUTO, CLK_SOURCE_HSE, DISABLE,
        //                CLK_CURRENTCLOCKSTATE_DISABLE);

	// ------------ UART1 -------------------
	UART1_DeInit();

	// 8N1
	UART1_Init((uint32_t)9600, UART1_WORDLENGTH_8D, UART1_STOPBITS_1, UART1_PARITY_NO,
              UART1_SYNCMODE_CLOCK_DISABLE, UART1_MODE_TXRX_ENABLE);


	enableInterrupts();
	i=0;
	for(;;)
  	{
		GPIO_WriteReverse(LED_PORT, LED);
		delay_ms(1000);

		printf("count: %u\n",++i);
  	}
}


PUTCHAR_PROTOTYPE
{
  	// Write a character to the UART1
  	UART1_SendData8(c);
  	// Loop until the end of transmission 
  	while (UART1_GetFlagStatus(UART1_FLAG_TXE) == RESET);
}
